# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import winrt.system
from winrt._winrt_windows_system_power_diagnostics import (
    BackgroundEnergyDiagnostics,
    ForegroundEnergyDiagnostics,
)

__all__ = [
    "BackgroundEnergyDiagnostics",
    "ForegroundEnergyDiagnostics",
]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class BackgroundEnergyDiagnostics_Static(winrt._winrt.IInspectable_Static):
    # System.UInt64 Windows.System.Power.Diagnostics.BackgroundEnergyDiagnostics::ComputeTotalEnergyUsage()
    # @deprecated("Background Energy Diagnostics has been deprecated. For more info, see MSDN.")
    def compute_total_energy_usage(cls) -> winrt.system.UInt64: ...
    # System.Void Windows.System.Power.Diagnostics.BackgroundEnergyDiagnostics::ResetTotalEnergyUsage()
    # @deprecated("Background Energy Diagnostics has been deprecated. For more info, see MSDN.")
    def reset_total_energy_usage(cls) -> None: ...
    # System.Double Windows.System.Power.Diagnostics.BackgroundEnergyDiagnostics::get_DeviceSpecificConversionFactor()
    @_property
    def device_specific_conversion_factor(cls) -> winrt.system.Double: ...

@typing.final
class BackgroundEnergyDiagnostics(winrt.system.Object, metaclass=BackgroundEnergyDiagnostics_Static):
    pass

@typing.final
class ForegroundEnergyDiagnostics_Static(winrt._winrt.IInspectable_Static):
    # System.UInt64 Windows.System.Power.Diagnostics.ForegroundEnergyDiagnostics::ComputeTotalEnergyUsage()
    # @deprecated("Background Energy Diagnostics has been deprecated. For more info, see MSDN.")
    def compute_total_energy_usage(cls) -> winrt.system.UInt64: ...
    # System.Void Windows.System.Power.Diagnostics.ForegroundEnergyDiagnostics::ResetTotalEnergyUsage()
    # @deprecated("Background Energy Diagnostics has been deprecated. For more info, see MSDN.")
    def reset_total_energy_usage(cls) -> None: ...
    # System.Double Windows.System.Power.Diagnostics.ForegroundEnergyDiagnostics::get_DeviceSpecificConversionFactor()
    @_property
    def device_specific_conversion_factor(cls) -> winrt.system.Double: ...

@typing.final
class ForegroundEnergyDiagnostics(winrt.system.Object, metaclass=ForegroundEnergyDiagnostics_Static):
    pass

